# Mixins package 
from acl_package.mixins.permission_mixin import PermissionMixin 
 
__all__ = ['PermissionMixin'] 
from acl_package.mixins.permission_mixin import PermissionMixin 
__all__ = ['PermissionMixin'] 
 



class RolePermission:

    def __init__(self,id,role_id,permission_id,created_at=None):
        self.id = id
        self.role_id = role_id
        self.permission_id = permission_id
        self.created_at = created_at


# Make acl_package a proper Python package
from acl_package.models.user import User
from acl_package.models.role import Role
from acl_package.models.permission import Permission
from acl_package.models.group import Group
from acl_package.models.object_permission import ObjectPermission
from acl_package.mixins.permission_mixin import PermissionMixin

__all__ = [
    'User', 'Role', 'Permission', 'Group', 
    'ObjectPermission', 'PermissionMixin'
]


class PermissionRegistry:
    def __init__(self):
        self.permissions = {}

    def add_permission(self, permission_obj):
        self.permissions[permission_obj.permission_name] = permission_obj



class GroupRole:
    def __init__(self, id, group_id, role_id, created_at=None):
        self.id = id
        self.group_id = group_id
        self.role_id = role_id
        self.created_at = created_at



from acl_package.mixins.permission_mixin import PermissionMixin

class User(PermissionMixin):
    def __init__(self, id, username, email, password, is_super_admin, is_admin, created_at=None):
        self.id = id
        self.username = username
        self.email = email
        self.password = password
        self.is_super_admin = is_super_admin
        self.is_admin = is_admin
        self.created_at = created_at
        self.roles = []
        self.groups = []
        self.object_permissions = []


class ObjectPermission:

    def __init__(self,id,user,group_id,object_type,object_id,permission_name,created_at=None):
        self.id = id
        self.user = user
        self.group_id = group_id
        self.object_type=object_type
        self.object_id=object_id
        self.permission_name=permission_name
        self.created_at = created_at

        




class Permission:
    def __init__(self, id, permission_name, label, created_at=None):
        self.id = id
        self.permission_name = permission_name
        self.label = label
        self.created_at = created_at


class UserRole:

    def __init__(self,id,user_id,role_id,created_at=None):
        self.id = id
        self.user_id = user_id
        self.role_id = role_id
        self.created_at = created_at

        


from acl_package.models.user import User 
from acl_package.models.role import Role 
from acl_package.models.permission import Permission 
from acl_package.models.group import Group 
from acl_package.models.user_role import UserRole 
from acl_package.models.user_group import UserGroup 
from acl_package.models.role_permission import RolePermission 
from acl_package.models.group_role import GroupRole 
from acl_package.models.object_permission import ObjectPermission 



class PermissionMixin:
    def has_perm(self, permission_name, obj_type=None, obj_id=None):
     
        if getattr(self, 'is_super_admin', False):
            return True

    
        for op in getattr(self, 'object_permissions', []):
            if op.permission_name == permission_name:
                if obj_type == op.object_type and obj_id == op.object_id:
                    return True

        for role in getattr(self, 'roles', []):
            for p in role.permissions:
                if p.permission_name == permission_name:
                    return True

        for group in getattr(self, 'groups', []):
            for role in group.roles:
                for p in role.permissions:
                    if p.permission_name == permission_name:
                        return True

        return False


from setuptools import setup, find_packages

setup(
    name='aclforall',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[], 
    author='Your Name',
    description='ACL package for permission management',
    python_requires='>=3.6',
)